==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/view/dokument_novy.php <==
<?php
/**
 * User: stanislav.elbl, 7.2.2015
 */

namespace Ron\RonPortal;

require_once('ron/controls.php');

use Ron\Controls\ComboBox;
use Ron\Http\App;
use Ron\MessageManager;
use Ron\StringUtils;

/** @var DokumentUploadForm $this */

if (!$this || !$this ->database) throw new \Exception('Chyba ve formulari pro vlozeni noveho dokumentu - neni nastavena database!');

?>
<div id="novydokument" title="<?= \Ron\ronText('Vlozit_novy_dokument') ?>"
    <?= $this ->redirectUrl ? 'data-redirect-url="' . StringUtils::htmlTextConvert($this ->redirectUrl) . '"' : '' ?>
     class="rondialog">

    <form action="<?= $this ->uploadUrl ?>" method="post" enctype="multipart/form-data" target="<?= $this ->target ?>" >

        <?php
            if ($this ->hiddenFields)
                foreach($this ->hiddenFields as $fieldName => $fieldValue) {
        ?>
                <input type="hidden" class="documentUploadInput" name="<?= $fieldName ?>" value="<?= $fieldValue ?>" />
        <?php
                }
        ?>

        <div>
            <?php if (is_null($this->typDokumentu)) { ?>
            <div class="row">
                <div class="col col-12 col-sm-4 caption required"><?= \Ron\ronText('Typ') ?></div>
                <div class="col col-12 col-sm-8">
                    <?php
                        $combo = new ComboBox('typ');
                        $combo ->dataTypeComparison = false;
                        try {
                            if (is_null($this->kategorieDokumentu)) {
                                $combo->loadData($this->database, 'SELECT Kod, Popis FROM TypDokumentu WHERE ZobrazitNaIntrawebu = 1 AND Kod >= 0 ORDER BY Kod', null);
                            } else {
                                $params = $this->database->createParameters();
                                $combo->loadData($this->database, 'SELECT Kod, Popis FROM TypDokumentu WHERE ZobrazitNaIntrawebu = 1 AND Kod >= 0 AND KategorieDokumentu = ' . $params->addParameter($this->kategorieDokumentu) . ' ORDER BY Kod', null, $params);
                            }
                        } catch (\Exception $exception) {
                            MessageManager::addErrorMessage(StringUtils::fromUTF8('Chyba při načítání typů dokumentu. ') . $exception->getMessage());
                        }
                        $combo ->className .= ' documentUploadInput form-input';
                        $combo ->render();
                    ?>
                </div>
            </div>
            <?php } ?>

            <div class="row">
                <div class="col col-12 col-sm-4 caption required"><?= \Ron\ronText('Popis') ?></div>
                <div class="col col-12 col-sm-8"><input type="text" class="documentUploadInput form-input" name="popis" size="60" maxlength="160"/></div>
            </div>

            <div class="row">
                <div class="col col-12 col-sm-4 caption"><?= \Ron\ronText('Nahrat_soubor') ?></div>
                <div class="col col-12 col-sm-8"><input type="file" name="soubor"></div>
            </div>

            <?php if ($this ->sqlPripojeniStarsiho) { ?>
                <div class="row" id="dokument_pripojit_nebo">
                    <div class="col col-0 col-sm-4"></div>
                    <div class="col col-12 col-sm-8"><?= \Ron\ronText('Nebo') ?></div>
                </div>
                <div class="row" id="dokument_pripojit_starsi">
                    <div class="col col-12 col-sm-4 caption"><?= \Ron\ronText('Pripojit_starsi_dokument') ?></div>
                    <div class="col col-12 col-sm-8">
                        <?php
                            $combodata = [' '];
                            try {
                                $cursor = $this->database->getSqlResult($this->sqlPripojeniStarsiho);
                                while ($row = $cursor ->fetch()) {
                                    $combodata[$row[0]] = StringUtils::format('date', $cursor ->stringToTimestamp($row[2])) . ' - ' . $row[1];
                                }
                                $cursor ->close();
                            } catch (\Exception $exception) {
                                MessageManager::addErrorMessage('Chyba pri nacitani zaznamu pro pripojeni dokumentu. ' . $exception->getMessage());
                            }

                            ComboBox::renderComboFromArray($combodata, 'pripojitdokument', '', ['id' => 'vyberStarsihoDokumentu', 'class' => 'form-input documentUploadInput']);
                        ?>
                    </div>
                </div>

            <?php } ?>

            <?php if( $this  &&  method_exists($this, 'dalsiRadkyKDokumentu') ) {
                $this ->dalsiRadkyKDokumentu();
            } ?>
        </div>

        <div class="buttons">
            <div>
                <input id="vlozitNovyDokumentBtn" type="submit" class="submitbutton" value="<?= \Ron\ronText('form.Insert') ?>" />
                <input id="stornoNovyDokumentBtn" type="button" class="button cancel" value="<?= \Ron\ronText('Cancel') ?>" />
            </div>


            <div id="novydokument_progressrow" class="d-none">
                <?= \Ron\ronText('Probiha_odesilani_souboru') ?>
            </div>

            <div id="novydokument_error"></div>
        </div>

    </form>

    <?php if ($this ->target) { ?>
    <iframe id="upload_target" name="upload_target" <?= App::getDebugMode() ? 'class="debug"' : '' ?> src=""></iframe>
    <?php } ?>
</div>

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/view/dokument_novy.php <==
<?php
/**
 * User: stanislav.elbl, 7.2.2015
 */

namespace Ron\RonPortal;

use Ron\Controls\ComboBox;
use Ron\Http\App;
use Ron\MessageManager;
use Ron\StringUtils;
use RonPortal\Security;

/** @var DokumentUploadForm $this */

if (!$this || !$this ->database) {
    throw new \Exception('Chyba ve formulari pro vlozeni noveho dokumentu - neni nastavena database!');
}

?>
<div id="novydokument" title="<?= \Ron\ronText('Vlozit_novy_dokument') ?>"
    <?= $this ->redirectUrl ? 'data-redirect-url="' . StringUtils::htmlTextConvert($this ->redirectUrl) . '"' : '' ?>
     class="rondialog">

    <form action="<?= $this ->uploadUrl ?>" method="post" enctype="multipart/form-data" target="<?= $this ->target ?>" >
        <?= Security::csrfHiddenInput(['class' => 'documentUploadInput']) ?>

        <?php
            if ($this ->hiddenFields)
                foreach($this ->hiddenFields as $fieldName => $fieldValue) {
        ?>
                <input type="hidden" class="documentUploadInput" name="<?= $fieldName ?>" value="<?= $fieldValue ?>" />
        <?php
                }
        ?>

        <div>
            <?php if (is_null($this->typDokumentu)) { ?>
            <div class="row">
                <div class="col col-12 col-sm-4 caption required"><?= \Ron\ronText('Typ') ?></div>
                <div class="col col-12 col-sm-8">
                    <?php
                        $combo = new ComboBox('typ');
                        $combo ->dataTypeComparison = false;
                        try {
                            if (is_null($this->kategorieDokumentu)) {
                                $combo->loadData($this->database, 'SELECT Kod, Popis FROM TypDokumentu WHERE ZobrazitNaIntrawebu = 1 AND Kod >= 0 ORDER BY Kod', null);
                            } else {
                                $params = $this->database->createParameters();
                                $combo->loadData($this->database,
                                    'SELECT Kod, Popis FROM TypDokumentu' .
                                    ' WHERE ZobrazitNaIntrawebu = 1 AND Kod >= 0 AND KategorieDokumentu = ' . $params->addParameter($this->kategorieDokumentu) .
                                    ' ORDER BY Kod',
                                    null, $params);
                            }
                        } catch (\Exception $exception) {
                            MessageManager::addErrorMessage(StringUtils::fromUTF8('Chyba pri nacitani typu dokumentu. ') . $exception->getMessage());
                        }
                        $combo ->className .= ' documentUploadInput form-input';
                        $combo ->render();
                    ?>
                </div>
            </div>
            <?php } ?>

            <div class="row">
                <div class="col col-12 col-sm-4 caption required"><?= \Ron\ronText('Popis') ?></div>
                <div class="col col-12 col-sm-8"><input type="text" class="documentUploadInput form-input" name="popis" size="60" maxlength="160"/></div>
            </div>

            <div class="row">
                <div class="col col-12 col-sm-4 caption"><?= \Ron\ronText('Nahrat_soubor') ?></div>
                <div class="col col-12 col-sm-8"><input type="file" name="soubor"></div>
            </div>

            <?php if ($this ->sqlPripojeniStarsiho) { ?>
                <div class="row" id="dokument_pripojit_nebo">
                    <div class="col col-0 col-sm-4"></div>
                    <div class="col col-12 col-sm-8"><?= \Ron\ronText('Nebo') ?></div>
                </div>
                <div class="row" id="dokument_pripojit_starsi">
                    <div class="col col-12 col-sm-4 caption"><?= \Ron\ronText('Pripojit_starsi_dokument') ?></div>
                    <div class="col col-12 col-sm-8">
                        <?php
                            $combodata = [' '];
                            try {
                                $cursor = $this->database->getSqlResult($this->sqlPripojeniStarsiho);
                                while ($row = $cursor ->fetch()) {
                                    $combodata[$row[0]] = StringUtils::format('date', $cursor ->stringToTimestamp($row[2])) . ' - ' . $row[1];
                                }
                                $cursor ->close();
                            } catch (\Exception $exception) {
                                MessageManager::addErrorMessage('Chyba pri nacitani zaznamu pro pripojeni dokumentu. ' . $exception->getMessage());
                            }

                            ComboBox::renderComboFromArray($combodata, 'pripojitdokument', '', ['id' => 'vyberStarsihoDokumentu', 'class' => 'form-input documentUploadInput']);
                        ?>
                    </div>
                </div>

            <?php } ?>

            <?php if( $this  &&  method_exists($this, 'dalsiRadkyKDokumentu') ) {
                $this ->dalsiRadkyKDokumentu();
            } ?>
        </div>

        <div class="buttons">
            <div>
                <input id="vlozitNovyDokumentBtn" type="submit" class="submitbutton" value="<?= \Ron\ronText('form.Insert') ?>" />
                <input id="stornoNovyDokumentBtn" type="button" class="button cancel" value="<?= \Ron\ronText('Cancel') ?>" />
            </div>


            <div id="novydokument_progressrow" class="d-none">
                <?= \Ron\ronText('Probiha_odesilani_souboru') ?>
            </div>

            <div id="novydokument_error"></div>
        </div>

    </form>

    <?php if ($this ->target) { ?>
    <iframe id="upload_target" name="upload_target" <?= App::getDebugMode() ? 'class="debug"' : '' ?> src=""></iframe>
    <?php } ?>
</div>
